import { select, 
        csv, 
        scaleLinear, 
        max, 
        axisLeft, 
        axisBottom,
       format,
       extent} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

			// d.mpg = +d.mpg;
			// d.cylinders = +d.cylinders;
			// d.displacement = +d.displacement;
			// d.horsepower = +d.horsepower;
			// d.weight = +d.weight;
			// d.acceleration = +d.acceleration;
			// d.year = +d.year;
               

const xValue = d => d.weight;
const xName = 'Weight';
const yValue = d => d.horsepower;
const yName = 'Horsepower';
const margin = {top: 50, right: 20, bottom:70, left:140};
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;


const render = data => {
  
  const xScale = scaleLinear()
					.domain(extent(data, xValue))
  				.range([0, innerWidth])
  				.nice();
  
  
  const yScale = scaleLinear()
  				.domain(extent(data, yValue))
  				.range([0, innerHeight])
  				.nice();
  				
  
  
  const yAxis = axisLeft(yScale)
  							.tickSize(-innerWidth);
  							
  const xAxis = axisBottom(xScale)
  								.tickFormat(format('.3s'))
  								.tickSize(-innerHeight)
  								.tickPadding(20);
  
  const g = svg.append('g')
  	.attr('transform',`translate(${margin.left},${margin.top})`);
  
  const yAxisG = g.append('g').call(yAxis);
  
  yAxisG
  		.select('.domain')
  			.remove();
  
  yAxisG.append('text')
  				.attr('y',-50)
  				.attr('x',-innerHeight / 2)
  				.style('fill', 'black')
  				.text(yName)
  				.style('text-anchor','middle')
  				.attr('transform','rotate(-90)')
  
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform',`translate(0, ${innerHeight})`);
  
  xAxisG
  	.select('.domain')
  		.remove();
  
  xAxisG.append('text')
  				.attr('y', 50)
  				.attr('x', innerWidth / 2)
  				.style('fill', 'black')
  				.text(xName);
  
  g.selectAll('circle').data(data)
  	.enter().append('circle')
  		.attr('cy', d => yScale(yValue(d)))
  		.attr('cx', d => xScale(xValue(d)))
  		.attr('r', 10);
  
  g.append('text')
  	.attr('y', -10)
  	.attr('x', innerWidth / 3)
  	.text('Top 10 Country');
  		
}

csv('https://vizhub.com/Braja123/datasets/auto-mpg.csv').then(data => {
  data.forEach(d => {
     	d.mpg = +d.mpg;
      d.cylinders = +d.cylinders;
      d.displacement = +d.displacement;
      d.horsepower = +d.horsepower;
      d.weight = +d.weight;
      d.acceleration = +d.acceleration;
      d.year = +d.year;
               
  })
  render(data);
})